# `googleapis-gen`

> [!NOTE]
>
> This package only generated
> [a few proto files](https://github.com/caiyunapp/googleapis-gen/blob/v0.1.2/buf.gen.yaml#L10-L16)
> from the upstream `googleapis` repository. It is not a full copy of the
> `googleapis` repository. Please refer to the upstream repository for the full
> set of proto files.
>
> The generated files are under the `google` namespace, to work with other
> generated codes.

Install:

```bash
pip install googleapis-gen
```

LICENSE:

- [Apache License 2.0](./LICENSE)
- Upstream:
  [googleapis/googleapis](https://github.com/googleapis/googleapis/blob/master/LICENSE)
  - or a copy: [LICENSE_GOOGLE](./LICENSE_GOOGLE)
